Cafe phim Hà Nội - Cine cafe - Thưởng thức phim, đồ ăn cùng người yêu, người thân trong không gian riêng của bạn tại cafe phim!
Author: cine cafe group
Description: Thưởng thức phim, đồ ăn cùng người yêu, người thân trong không gian riêng của bạn tại cafe phim!
Keywords: cafe phim, cafe phim Hà Nội

Cs1: 0966 399 822 Cs2: 0986 231 166
Dự toán chi phí ( 0 đ )

- # Hitman: Agent 47 (2015) – Sát Thủ: Mật Danh 47

  Trong SÃ¡t Thá»§: Máºt Danh 47 (Hitman: Agent 47) bÃ máºt Ä‘Æ°á»£c hÃ© lá»™ khi â€œ47â€ chÃnh lÃ má»™t ngÆ°á»i nhÃ¢n táº¡o Ä‘Æ°á»£c biáº¿n Ä‘á»•i gien, lÃ sáº£n pháº©m cuá»‘i cÃ¹ng tá»« má»™t dá»± Ã¡n khoa há»c nháº±m táº¡o ra má»™t Ä‘á»™i quÃ¢n siÃªu háº¡ng vá»›i sá»©c máº¡nh, tá»‘c Ä‘á»™, sá»± dáº»o dai vÃ trÃ thÃ´ng minh vÆ°á»£t trá»™i ngÆ°á»i thÆ°á»ng...

  Chi Tiết
  Số lượng:
  Đặt Phòng

- # Tình + Tình (2015)

  Bá»™ phim xoay quanh gia Ä‘Ã¬nh Nam (Quá»‘c CÆ°á»ng) vÃ Minh Háº¡nh (HoÃ ng Ny). Há» cÃ³ má»™t cuá»™c sá»‘ng yÃªn bÃ¬nh cÃ¹ng con gÃ¡i tuÃ´Ì‰i 15, cho Ä‘áº¿n má»™t ngÃ y Nam gáº·p gá»¡ ThÃ¹y Linh (LÃª Kiá»u NhÆ°) vÃ lÃºn sÃ¢u vÃ o cuá»™c tiÌ€nh ngoáº¡i tuyáº¿n...

  Chi Tiết
  Số lượng:
  Đặt Phòng

- # The Visit (2015) – 9 Rưỡi Tối

  9 RÆ¯á» I Tá»I lÃ cÃ¢u chuyá»‡n vá» nhá»¯ng tráº£i nghiá»‡m kinh hoÃ ng cá»§a hai chá»‹ em Becca (Olivia Dejonge) vÃ Tyler (Ed Oxenbould) trong chuyáº¿n viáº¿ng thÄƒm Ã´ng bÃ á»Ÿ vÃ¹ng nÃ´ng thÃ´n bang Pennsylvania...

  Chi Tiết
  Số lượng:
  Đặt Phòng

- # Inside Out (2015) – Những Mảnh Ghép Cảm Xúc

  Riley, má»™t bÃ© gÃ¡i 11 tuá»•i, buá»™c pháº£i rá»i khá»i cuá»™c sá»‘ng cá»§a mÃ¬nh táº¡i Midwest khi cha cÃ´ báº¯t Ä‘áº§u cÃ´ng viá»‡c má»›i táº¡i San Francisco. Riley (Kaitlyn Dias) Ä‘Æ°á»£c dáº«n dáº¯t bá»Ÿi cÃ¡c cáº£m xÃºc - Joy (Amy Poehler), Fear (Bill Hader), Anger (Lewis Black), Disgust (Mindy Kaling) vÃ Sadness (Phyllis Smith)...

  Chi Tiết
  Số lượng:
  Đặt Phòng

- # Pixels (2015) – Đại Chiến Pixels

  CÃ¢u chuyá»‡n cá»§a Pixels Ä‘Æ°á»£c khá»Ÿi Ä‘áº§u tá»« má»™t phi thuyá»n thá»i gian chá»©a thÃ´ng Ä‘iá»‡p hÃ²a bÃ¬nh, gá»“m cÃ¡c vÃ dá»¥ vá» cuá»™c sá»‘ng vÃ vÄƒn hÃ³a cá»§a loÃ i ngÆ°á»i Ä‘Æ°á»£c NASA gá»i Ä‘i nÄƒm 1982 vá»›i hi vá»ng tÃ¬m kiáº¿m cÃ¡c thá»±c thá»ƒ sá»‘ng khÃ¡c. Tuy nhiÃªn, phi thuyá»n nÃ y láº¡i Ä‘Æ°á»£c gá»i Ä‘i khÃ´ng Ä‘Ãºng cÃ¡ch, khiáº¿n cho nhá»¯ng ngÆ°á»i ngoÃ i hÃ nh tinh dá»‹ch sai thÃ nh thÃ´ng Ä‘iá»‡p Ä‘e dá»a, vÃ tiáº¿n hÃ nh Ä‘á»• bá»™ xÃ¢m chiáº¿m trÃ¡i Ä‘áº¥t...

  Chi Tiết
  Số lượng:
  Đặt Phòng

- # Tèo Em (2013)

  Trong TÈO EM, diễn viên Thái Hòa và Johnny Trí Nguyễn vào vai hai nhân vật sống ở hai thế giới khác nhau – người lanh lợi, lịch lãm - kẻ cù lần, ngây ngô. Họ buộc phải lên cùng chuyến xe định mệnh đi về thị xã Sa Đéc, chạy đua với thời gian nhằm cứu vãn một mối tình...

  Chi Tiết
  Số lượng:
  Đặt Phòng

- # Fantastic Four (2015) – Bộ Tứ Siêu Đẳng

  Phim xoay quanh sá»± hÃ¬nh thÃ nh cá»§a Bá»™ tá»© siÃªu Ä‘áº³ng. Tiáº¿n sá»¹ váºt lÃ½ tráº» Reed Richards cÃ¹ng phi hÃ nh gia Ben Grimm, báº¡n gÃ¡i cÅ© Susan Storm vÃ anh chÃ ng Johnny Storm tham gia vÃ o má»™t cuá»™c thá» nghiá»‡m ngoÃ i vÅ© trá»¥. Khi trá»Ÿ vá», há» phÃ¡t hiá»‡n ra cÆ¡ thá»ƒ mÃ¬nh Ä‘Ã£ bá»‹ biáº¿n Ä‘á»•i má»™t cÃ¡ch ká»³ láº¡: Richards cÃ³ thá»ƒ kÃ©o dÃ i ngÆ°á»i nhÆ° cao su, Susan Storm cÃ³ thá»ƒ trá»Ÿ nÃªn vÃ´ hÃ¬nh vÃ táº¡o ra má»™t nguá»“n nÄƒng lÆ°á»£ng lÃ m lÃ¡ cháº¯n, Johnny Storm cÃ³ kháº£ nÄƒng tá»± bá»‘c chÃ¡y vÃ bay, cÃ²n Grimm trá»Ÿ thÃ nh má»™t ngÆ°á»i Ä‘Ã¡ vá»›i sá»©c máº¡nh khá»§ng khiáº¿p.

  Chi Tiết
  Số lượng:
  Đặt Phòng

- # Mission: Impossible Rogue Nation (2015) – Nhiệm Vụ Bất Khả Thi 5: Quốc Gia Bí Ẩn

  Mission Impossible 5: Rogue Nation - Nhiá»‡m vá»¥ báº¥t kháº£ thi 5: Quá»‘c gia dá»‘i trÃ¡: lÃ pháº§n thá»© 5 trong loáº¡t phim hÃ nh Ä‘á»™ng bom táº¥n vá» Ä‘iá»‡p viÃªn ná»•i tiáº¿ng. TÃ i tá» Ä‘iá»ƒn trai Tom Cruise quay láº¡i vá»›i nhÃ¢n váºt biá»ƒu tÆ°á»£ng Ethan Hunt, láº§n nÃ y sáº½ pháº£i thá»±c hiá»‡n má»™t nhiá»‡m vá»¥ siÃªu khÃ³ khÄƒn: tiÃªu diá»‡t cáº£ má»™t tá»• chá»©c lá»«a Ä‘áº£o xuyÃªn quá»‘c gia Syndicate â€“ nÆ¡i táºp há»£p nhá»¯ng sÃ¡t thá»§ thÃ´ng minh vÃ nguy hiá»ƒm nháº¥t.

  Chi Tiết
  Số lượng:
  Đặt Phòng

- # Tomorrowland (2015) – Thế Giới Bí Ẩn

  Má»™t Ä‘á»™i quÃ¢n chÆ°a rÃµ danh tÃnh tuyÃªn bá»‘ nhÃ sÃ¡ng cháº¿ Frank Walker Ä‘ang chá»©a cháº¥p má»™t pháº§n tá» bá» trá»‘n, trong khi bÃªn cáº¡nh Ã´ng chá»‰ lÃ cÃ´ bÃ© Casey Newton â€“ ngÆ°á»i má»›i mang chiáº¿c cÃ i Ã¡o ká»³ láº¡ tá»›i há»i Frank. Cuá»™c rÆ°á»£t Ä‘uá»•i diá»…n ra vÃ´ cÃ¹ng ká»‹ch tÃnh trong cÄƒn nhÃ Ä‘áº§y ráº«y nhá»¯ng vÅ© khÃ, Ä‘á»“ váºt vÃ cáº¡m báº«y cÃ´ng nghá»‡ cao. Chuyáº¿n phiÃªu lÆ°u cá»§a Frank vÃ Casey tiáº¿p tá»¥c trong má»™t cá»— mÃ¡y xuyÃªn thá»i gian vÃ khÃ´ng gian tá»›i tháº¿ giá»›i bÃ áº©n..

  Chi Tiết
  Số lượng:
  Đặt Phòng

- # Minions

  CÃ¢u chuyá»‡n ká»ƒ vá» cÃ¡c MINION trÆ°á»›c khi gáº·p chá»§ nhÃ¢n Gru (xuáº¥t hiá»‡n á»Ÿ 2 pháº§n Káº» Cáº¯p Máº·t TrÄƒng trÆ°á»›c), báº¯t Ä‘áº§u tá»« buá»•i bÃ¬nh minh cá»§a nhÃ¢n loáº¡i, xuáº¥t phÃ¡t Ä‘iá»ƒm lÃ nhá»¯ng sinh váºt Ä‘Æ¡n bÃ o mÃ u vÃ ng, Minion dáº§n tiáº¿n hÃ³a qua cÃ¡c thá»i Ä‘áº¡i vÃ luÃ´n trung thÃ nh phá»¥ng sá»± nhá»¯ng káº» xáº¥u xa, tÃ n Ã¡c nháº¥t...

  Chi Tiết
  Số lượng:
  Đặt Phòng

- # Bộ Ba Rắc Rối

  Ná»™i dung phim Bá»™ Ba Ráº¯c Rá»‘i ká»ƒ vá» cÃ¢u chuyá»‡n cá»§a 3 cÃ´ gÃ¡i xa láº¡ Má»¹, Dung vÃ Vy trong má»™t Ä‘Ãªm vui chÆ¡i táº¡i há»™p Ä‘Ãªm cáº£ 3 Ä‘á»u say bÃ tá»‰ vÃ Ä‘áº¿n sÃ¡ng há» chá»£t nháºn ra mÃ¬nh Ä‘ang á»Ÿ má»™t bÃ£i biá»ƒn Ä‘áº§y rÃ¡c cá»§a bá»¯a tiá»‡c. 3 cÃ´ nÃ ng Ä‘Æ°á»£c Ã´ng Tuáº¥n Ä‘áº¡i gia má»i Ä‘á»n Ä‘á»ƒ truy tÃ¬m má»™t cÃ¡i ba lÃ´ chÆ°a bÃ¡u váºt, khÃ´ng ngáº§n ngáº¡i suy nghÄ© há» láºp tá»©c Ä‘á»“ng Ã½ dáº¥n thÃ¢n vÃ o cuá»™c phiÃªu lÆ°u Ä‘áº§y thÃº vá»‹ qua nhiá»u danh lam tháº¯ng cáº£nh cá»§a Viá»‡t Nam vÃ Ä‘áº±ng sau Ä‘Ã³ lÃ sá»± truy Ä‘uá»•i cá»§a bá»n xÃ£ há»™i Ä‘en.

  Chi Tiết
  Số lượng:
  Đặt Phòng

- # ALOHA

  Trong phim ALOHA, Bradley Cooper vÃ o vai Brian Gilcrest - má»™t nhÃ tháº§u quÃ¢n sá»± ná»•i danh, vÃ´ tÃ¬nh rÆ¡i vÃ o lÆ°á»›i tÃ¬nh cÃ¹ng vá»›i hai ngÆ°á»i phá»¥ ná»¯ lÃ Tracy (Rachel McAdams) vÃ NG (Emma Stone thá»§ vai), vÃ tá»± Ä‘áº©y mÃ¬nh vÃ o má»‘i quan há»‡ tay ba láº¯m ráº¯c rá»‘i láº«n thÄƒng tráº§m

  Chi Tiết
  Số lượng:
  Đặt Phòng

- # MA DAI

  Ná»™i dung xoay quanh má»‘i tÃ¬nh tay ba cá»§a hai ngÆ°á»i Ä‘Ã n Ã´ng tÃªn Thá»‘ vÃ VÄ©nh dÃ nh cho cÃ´ gÃ¡i xinh Ä‘áº¹p lÃ Lam Ä‘á»“ng thá»i vá»›i sá»± gÃ³p máº·t cá»§a 1 nhÃ¢n váºt khÃ¡ Ä‘áº·c biá»‡t lÃ má»™t há»“n ma luÃ´n Ä‘eo bÃ¡m cÃ´ nÃ ng Lam Ä‘á»ƒ Ä‘Æ°a ra nhá»¯ng gá»£i Ã½ vá» tÃ¬nh yÃªu..

  Chi Tiết
  Số lượng:
  Đặt Phòng

- # BIỆT ĐỘI SIÊU ANH HÙNG 2: ĐẾ CHẾ ULTRON

  Trong pháº§n nÃ y, biá»‡t Ä‘á»™i siÃªu anh hÃ¹ng cá»§a chÃºng ta sáº½ pháº£i chiáº¿n Ä‘áº¥u vá»›i binh Ä‘oÃ n robot Ä‘Æ°á»£c biáº¿t Ä‘áº¿n vá»›i cÃ¡i tÃªn lÃ Ultron.

  Chi Tiết
  Số lượng:
  Đặt Phòng

- # KHE NỨT SAN ANDREAS

  Sau má»™t cÆ¡n Ä‘á»‹a cháº¥n kinh hoÃ ng, cáº£ thÃ nh phá»‘ chÃ¬m trong Ä‘á»• nÃ¡t, máº·t Ä‘áº¥t tÃ¡ch lÃ m Ä‘Ã´i vÃ Ray (Dwayne Johnson) - má»™t phi cÃ´ng thuá»™c Ä‘á»™i cá»©u há»™ tuáº§n tra Ä‘ang rong ruá»•i kháº¯p nÆ¡i trÃªn trá»±c thÄƒng vá»›i hy vá»ng giáº£i cá»©u cÃ´ con gÃ¡i Ä‘ang máº¥t tÃch trÆ°á»›c khi cÆ¡n sÃ³ng tháº§n áºp Ä‘áº¿n.

  Chi Tiết
  Số lượng:
  Đặt Phòng

- # You Are My Sunshine – Bên Nhau Trọn Đời (2015)

  Bá»™ phim BÃªn Nhau Trá»n Äá»i(PhiÃªn báº£n Ä‘iá»‡n áº£nh) chuyá»ƒn thá»ƒ tá»« tiá»ƒu thuyáº¿t cÃ¹ng tÃªn cá»§a tÃ¡c giáº£ Cá»‘ Máº¡n

  Chi Tiết
  Số lượng:
  Đặt Phòng

- # Terminator Genisys – Kẻ Hủy Diệt 5: Thời Đại Genisys (2015)

  Pháº§n 5 cá»§a Káº» há»§y diá»‡t sáº½ táºp trung vÃ o sá»± kiá»‡n trÆ°á»›c khi Sarah Connor biáº¿n máº¥t vÃ o khoáº£ng giá»¯a Terminator 2: Judgment Day vÃ Terminator 3: Rise of the Machines. Trong khoáº£ng thá»i gian nÃ y ngÆ°á»i xem sáº½ tiáº¿p xÃºc vá»›i hÃ¬nh hÃ i tháºt sá»± cá»§a Káº» há»§y diá»‡t T-800 á»Ÿ dáº¡ng con ngÆ°á»i, vÃ Ä‘á»“ng nghÄ©a vá»›i viá»‡c sau nÃ y táº¡i sao hÃ¬nh máº«u cá»§a nhÃ¢n váºt Ä‘Æ°á»£c Skynet lá»±a cho cÃ¡c láº§n Ä‘Æ°a vá» quÃ¡ khá»© sau nÃ y...

  Chi Tiết
  Số lượng:
  Đặt Phòng

- # Con đường bất tận – The Longest Ride

  Láº¥y bá»‘i cáº£nh á»Ÿ Báº¯c Carolina vá»›i nhá»¯ng cÃ¡nh rá»«ng ngáºp trÃ n Ã¡nh náº¯ng, The Longest Ride xoay quanh hai chuyá»‡n tÃ¬nh xáº£y ra á»Ÿ hai thá»i Ä‘iá»ƒm khÃ¡c nhau.

  Chi Tiết
  Số lượng:
  Đặt Phòng

‹ ›
CineCafe - Thế giới của những người yêu phim
Xem toàn bộ phim

- ## Hitman: Agent 47 (2015) – Sát Thủ: Mật Danh 47

  Trailer Chi tiết
  Số lượng:
  Đặt phòng

- ## Tình + Tình (2015)

  Trailer Chi tiết
  Số lượng:
  Đặt phòng

- ## The Visit (2015) – 9 Rưỡi Tối

  Trailer Chi tiết
  Số lượng:
  Đặt phòng

- ## Inside Out (2015) – Những Mảnh Ghép Cảm Xúc

  Trailer Chi tiết
  Số lượng:
  Đặt phòng

‹ ›

### ĐẶT PHÒNG XEM PHIM SIÊU TỐC ĐỂ NHẬN FREE 02 ĐỒ UỐNG TÙY CHỌN

### Tưng bừng khai trương Cafe phim CINE – Cơ sở 2

### Giảm giá xem phim đến 40% với Foody Ecard!!

### Xem phim giờ vàng tại Cafe phim CINE- 59K/1h